@@ -7,13 +7,16 @@ import glob
 import os
 from shutil import copy2
 import json
+
+from scp import SCPException
+
 from .args import Args
 from .task_runner import Task, StationTask, task_fwd_queue, task_bwd_queue, task_finished_queue, YumiTask
 import threading
 from .utils import SingletonMeta, locked, acquire_lock
 from flask_restful import Api
 import logging
-from .ssh import SSHClient
+from .ssh import SSHClient, copy_file_ssh
 import time
 import base64
 import queue
@@ -123,7 +126,7 @@ class CheckFunction(Resource):
                             self.logger.debug("Barcode is valid and stage is external")
                             while not BarcodeSingleton():
                                 self.logger.debug("Requesting barcode (exit)")
-                                BarcodeSingleton.reset(requests.get("http://127.0.0.1:{}/exit".format(Args().barcode_port)).content.decode('ascii'))
+                                BarcodeSingleton.reset(requests.get("http://127.0.0.1:{}/exit".format(Args().barcode_port)).content.decode('utf-8'))
                         if not BarcodeSingleton.valid and not output.get("external", True):
                             self.logger.debug("Barcode is not valid and stage is internal. Resetting barcode")
                             BarcodeSingleton.reset()
@@ -136,7 +139,10 @@ class CheckFunction(Resource):
                                output.get("status", None),
                                output.get("stage", None),
                                "\n\n{}".format(output["msg"]) if output.get("msg", None) else ""
-                           )
+                           ),
+                           "runinfo": {
+                               "stage": output.get("stage", None)
+                           }
                        }, 200
             elif issubclass(task_type, YumiTask):
                 return {
@@ -195,20 +201,39 @@ class CheckFunction(Resource):
                     log_remote = CheckFunction.bak().get("runlog", None)
                     log_local = Args().log_local.format(time.strftime("%Y_%m_%d__%H_%M_%S"))
                     if log_remote:
-                        os.makedirs(os.path.dirname(log_local), exist_ok=True)
                         try:
-                            with SSHClient() as client:
-                                with client.scp_client() as scp_client:
-                                    scp_client.get(log_remote, log_local)
+                            copy_file_ssh(log_remote, log_local)
                         except Exception as e:
                             self.logger.warning("Could not copy runlog from '{}' to '{}':\n{}".format(log_remote, log_local, e))
                         else:
                             self.logger.info("Copied runlog from '{}' to '{}'".format(log_remote, log_local))
+                exception_log_filepath = CheckFunction.bak().get('exceptionlog', None)
                 CheckFunction.bak({})
                 if code:
-                    return {"message": "Protocol execution {}. Exit code: {}".format(res, code)}, 500
+                    return {"message": "Protocol execution {} with exit code: {}. Message: {}".format(
+                                            res,
+                                            code,
+                                            self.get_error_from_remote_exception_file(exception_log_filepath))
+                            }, 503
                 return {"status": True, "res": res, "exit_code": code}, 200
 
+    def get_error_from_remote_exception_file(self, remote_exception_log_filepath: str) -> str:
+        if remote_exception_log_filepath:
+            filename = os.path.basename(os.path.normpath(remote_exception_log_filepath))
+            temp_path = os.path.join(Args().temp_data_dir, filename)
+            self.logger.debug("Copying to temporary file: {}".format(temp_path))
+            try:
+                copy_file_ssh(remote_exception_log_filepath, temp_path)
+            except SCPException as e:
+                self.logger.error("Error copying file {} to {}: {}".format(remote_exception_log_filepath, temp_path, e))
+            else:
+                self.logger.info("Copied {} to {}".format(remote_exception_log_filepath, temp_path))
+                with open(temp_path, 'r') as f:
+                    error = json.load(f).get('error', None)
+                # os.remove(temp_path)
+                return error
+        self.logger.error("Remote error filename is empty.")
+        return "unknown; see error file on robot."
 
 class PauseFunction(Resource):
     def get(self):
@@ -242,7 +267,7 @@ class ResumeFunction(Resource):
                 if BarcodeSingleton() and BarcodeSingleton.valid:
                     self.logger.debug("Requesting barcode (enter)")
                     try:
-                        while requests.get("http://127.0.0.1:{}/enter".format(Args().barcode_port)).content.decode('ascii') != BarcodeSingleton():
+                        while requests.get("http://127.0.0.1:{}/enter".format(Args().barcode_port)).content.decode('utf-8') != BarcodeSingleton():
                             pass
                     except Exception as e:
                         r = {"status": False, "res": str(e)}, 500
